@@ -22,6 +22,21 @@ pub mod font;
 pub mod form;
 pub mod metadata;
 pub mod page;
+pub mod page_annotation;
+pub mod page_annotation_circle;
+pub mod page_annotation_free_text;
+pub mod page_annotation_highlight;
+pub mod page_annotation_ink;
+pub mod page_annotation_link;
+pub mod page_annotation_popup;
+pub mod page_annotation_square;
+pub mod page_annotation_squiggly;
+pub mod page_annotation_stamp;
+pub mod page_annotation_strikeout;
+pub mod page_annotation_text;
+pub mod page_annotation_underline;
+pub mod page_annotation_unsupported;
+pub mod page_annotations;
 pub mod page_boundaries;
 pub mod page_object;
 pub mod page_object_form_fragment;
@@ -37,6 +52,25 @@ pub mod pages;
 pub mod pdfium;
 mod utils;
 
+/// A prelude for conveniently importing all public `pdfium-render` functionality at once.
+///
+/// Usage: `use pdfium_render::prelude::*`;
+pub mod prelude {
+    pub use super::{
+        action::*, action_destination::*, bindings::*, bitmap::*, bitmap_config::*, bookmark::*,
+        bookmarks::*, color::*, document::*, error::*, font::*, form::*, metadata::*, page::*,
+        page_annotation::*, page_annotation_circle::*, page_annotation_free_text::*,
+        page_annotation_highlight::*, page_annotation_ink::*, page_annotation_link::*,
+        page_annotation_popup::*, page_annotation_square::*, page_annotation_squiggly::*,
+        page_annotation_stamp::*, page_annotation_strikeout::*, page_annotation_text::*,
+        page_annotation_underline::*, page_annotation_unsupported::*, page_annotations::*,
+        page_boundaries::*, page_object::*, page_object_form_fragment::*, page_object_image::*,
+        page_object_path::*, page_object_shading::*, page_object_text::*,
+        page_object_unsupported::*, page_objects::*, page_size::*, page_text::*, pages::*,
+        pdfium::*,
+    };
+}
+
 // Conditional compilation is used to compile different implementations of
 // the PdfiumLibraryBindings trait depending on whether we are compiling to a
 // WASM module or to a native shared library.
@@ -49,9 +83,7 @@ mod wasm;
 
 #[cfg(test)]
 pub mod tests {
-    use crate::bitmap::PdfBitmapRotation;
-    use crate::bitmap_config::PdfBitmapConfig;
-    use crate::pdfium::Pdfium;
+    use crate::prelude::*;
     use image::ImageFormat;
 
     #[test]
